@@ -17,7 +17,7 @@ from nctoolkit.cleanup import cleanup, clean_all, temp_check
 from nctoolkit.flatten import str_flatten
 from nctoolkit.runthis import run_cdo
 from nctoolkit.session import nc_protected, session_info, nc_safe
-from nctoolkit.show import nc_variables, nc_years, nc_months, nc_levels, nc_times
+from nctoolkit.show import nc_variables, nc_years, nc_months, nc_levels, nc_times, nc_format
 from nctoolkit.temp_file import temp_file
 
 
@@ -59,7 +59,7 @@ temp_check()
 def is_url(x):
     regex = re.compile(
         r"^(?:http|ftp)s?://"  # http:// or https://
-        r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"  # domain...
+        r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"
         r"localhost|"  # localhost...
         r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})"  # ...or ip
         r"(?::\d+)?"  # optional port
@@ -139,7 +139,9 @@ def open_data(x=None, suppress_messages=False, checks=False, **kwargs):
     Parameters
     ---------------
     x : str or list
-        A string or list of netcdf files or a single url. The function will check the files exist. If x is not a list, but an iterable it will be converted to a list. If a url is given the file will be downloaded before processing.
+        A string or list of netcdf files or a single url. The function will check the
+        files exist. If x is not a list, but an iterable it will be converted to a list.
+        If a url is given the file will be downloaded before processing.
     thredds : boolean
         Are you accessing a thredds server? Must end with .nc.
     checks: boolean
@@ -290,7 +292,10 @@ def open_thredds(x=None):
         A string or list of thredds urls, which must end with .nc.
 
     """
-    return open_data(x = x, thredds = True)
+
+    if session_info["cores"] > 1:
+        warnings.warn(message="Using multiple cores on thredds data is volatile. If there is an error set cores=1.")
+    return open_data(x=x, thredds=True)
 
 
 def open_url(x=None):
@@ -300,10 +305,11 @@ def open_url(x=None):
     Parameters
     ---------------
     x : str
-        A string with a url. Prior to processing data will be downloaded to a temp folder.
+        A string with a url. Prior to processing data will be downloaded to
+        a temp folder.
 
     """
-    return open_data(x = x)
+    return open_data(x=x)
 
 
 def merge(*datasets, match=["day", "year", "month"]):
@@ -315,7 +321,10 @@ def merge(*datasets, match=["day", "year", "month"]):
     datasets: kwargs
         Datasets to merge.
     match: list
-        Temporal matching criteria. This is a list which must be made up of a subset of day, year, month. This checks that the datasets have compatible times. For example, if you want to ensure the datasets have the same years, then use match = ["year"].
+        Temporal matching criteria. This is a list which must be made up of a subset of
+        day, year, month. This checks that the datasets have compatible times.
+        For example, if you want to ensure the datasets have the same years, then use
+        match = ["year"].
     """
     all_files = []
     for dataset in datasets:
@@ -335,7 +344,9 @@ def merge(*datasets, match=["day", "year", "month"]):
 def cor_time(x=None, y=None):
     """
     Calculate the temporal correlation coefficient between two datasets
-    This will calculate the temporal correlation coefficient, for each time step, between two datasets. The datasets must either have the same variables or only have one variable.
+    This will calculate the temporal correlation coefficient, for each time step,
+    between two datasets. The datasets must either have the same variables or only
+    have one variable.
 
     Parameters
     -------------
@@ -361,7 +372,8 @@ def cor_time(x=None, y=None):
     if x.variables != y.variables:
         if len(x.variables) > 1 or len(y.variables) > 1:
             raise ValueError(
-                "This method currently only works with single variable datasets or datasets with identical variables!"
+                "This method currently only works with single variable datasets or "
+                "datasets with identical variables!"
             )
 
     target = temp_file("nc")
@@ -383,7 +395,9 @@ def cor_time(x=None, y=None):
 def cor_space(x=None, y=None):
     """
     Calculate the spatial correlation coefficient between two datasets
-    This will calculate the spatial correlation coefficient, for each time step, between two datasets. The datasets must either have the same variables or only have one variable.
+    This will calculate the spatial correlation coefficient, for each time step,
+    between two datasets. The datasets must either have the same variables or only
+    have one variable.
 
     Parameters
     -------------
@@ -409,7 +423,8 @@ def cor_space(x=None, y=None):
     if x.variables != y.variables:
         if len(x.variables) > 1 or len(y.variables) > 1:
             raise ValueError(
-                "This method currently only works with single variable datasets or datasets with identical variables!"
+                    "This method currently only works with single variable datasets "
+                    "or datasets with identical variables!"
             )
 
     target = temp_file("nc")
@@ -516,7 +531,8 @@ class DataSet(object):
     @property
     def size(self):
         """The size of an object
-        This will print the number of files, total size, and smallest and largest files in an DataSet object.
+        This will print the number of files, total size, and smallest and largest files
+        in an DataSet object.
         """
         if type(self.current) is str:
             result = "Number of files: 1\n"
@@ -623,6 +639,22 @@ class DataSet(object):
 
         return all_times
 
+    @property
+    def ncformat(self):
+        """
+        List formats of files contained in a dataset
+        """
+
+        all_formats = []
+        for ff in self:
+            all_formats+= nc_format(ff)
+
+        all_formats = list(set(all_formats))
+
+        all_formats.sort()
+
+        return all_formats
+
     @property
     def years(self):
         """
@@ -647,7 +679,8 @@ class DataSet(object):
         """
 
         if type(self.current) is list:
-            return "This DataSet object is a list. Please inspect individual files using nc_variables"
+            return "This DataSet object is a list. Please inspect individual"\
+                    "files using nc_variables"
 
         cdo_result = subprocess.run(
             "cdo showname " + self.current,
@@ -793,11 +826,45 @@ class DataSet(object):
     def start(self):
         raise AttributeError("You cannot delete the start point")
 
-    from nctoolkit.toxarray import to_xarray
-    from nctoolkit.toxarray import to_dataframe
+    # import the methods
 
+    from nctoolkit.add_etc import add
+    from nctoolkit.add_etc import subtract
+    from nctoolkit.add_etc import multiply
+    from nctoolkit.add_etc import divide
+
+    from nctoolkit.anomaly import annual_anomaly
+    from nctoolkit.anomaly import monthly_anomaly
+
+    from nctoolkit.append import append
+
+    from nctoolkit.cdo_command import cdo_command
     from nctoolkit.cellareas import cell_areas
-    from nctoolkit.regrid import regrid
+
+    from nctoolkit.centres import centre
+
+    from nctoolkit.cleanup import disk_clean
+
+
+    from nctoolkit.compare import compare_all
+
+    from nctoolkit.corr import cor_space
+    from nctoolkit.corr import cor_time
+
+    from nctoolkit.crop import crop
+
+    from nctoolkit.dailyclim import daily_mean_climatology
+    from nctoolkit.dailyclim import daily_min_climatology
+    from nctoolkit.dailyclim import daily_max_climatology
+    from nctoolkit.dailyclim import daily_range_climatology
+
+    from nctoolkit.dailystat import daily_mean
+    from nctoolkit.dailystat import daily_min
+    from nctoolkit.dailystat import daily_max
+    from nctoolkit.dailystat import daily_range
+    from nctoolkit.dailystat import daily_sum
+
+    from nctoolkit.delete import remove_variables
 
     from nctoolkit.ensembles import ensemble_mean
     from nctoolkit.ensembles import ensemble_max
@@ -805,35 +872,31 @@ class DataSet(object):
     from nctoolkit.ensembles import ensemble_range
     from nctoolkit.ensembles import ensemble_percentile
 
-    from nctoolkit.clip import clip
-    from nctoolkit.select import select_variables
-    from nctoolkit.select import select_timestep
-
-    from nctoolkit.cdo_command import cdo_command
-    from nctoolkit.nco_command import nco_command
-
     from nctoolkit.expr import mutate
     from nctoolkit.expr import transmute
     from nctoolkit.expr import sum_all
 
-    from nctoolkit.select import select_season
-    from nctoolkit.select import select_months
-    from nctoolkit.select import select_years
+    from nctoolkit.fldstat import spatial_mean
+    from nctoolkit.fldstat import spatial_min
+    from nctoolkit.fldstat import spatial_max
+    from nctoolkit.fldstat import spatial_range
+    from nctoolkit.fldstat import spatial_sum
+    from nctoolkit.fldstat import spatial_percentile
 
-    from nctoolkit.seasstat import seasonal_mean
-    from nctoolkit.seasstat import seasonal_min
-    from nctoolkit.seasstat import seasonal_max
-    from nctoolkit.seasstat import seasonal_range
+    from nctoolkit.format import format
 
-    from nctoolkit.seasclim import seasonal_mean_climatology
-    from nctoolkit.seasclim import seasonal_min_climatology
-    from nctoolkit.seasclim import seasonal_max_climatology
-    from nctoolkit.seasclim import seasonal_range_climatology
+    from nctoolkit.inttime import time_interp
+    from nctoolkit.inttime import timestep_interp
 
-    from nctoolkit.yearlystat import annual_mean
-    from nctoolkit.yearlystat import annual_min
-    from nctoolkit.yearlystat import annual_max
-    from nctoolkit.yearlystat import annual_range
+    from nctoolkit.masking import mask_box
+
+    from nctoolkit.mergers import merge_time
+    from nctoolkit.mergers import merge
+
+    from nctoolkit.meridonials import meridonial_mean
+    from nctoolkit.meridonials import meridonial_min
+    from nctoolkit.meridonials import meridonial_max
+    from nctoolkit.meridonials import meridonial_range
 
     from nctoolkit.monstat import monthly_mean
     from nctoolkit.monstat import monthly_min
@@ -845,36 +908,23 @@ class DataSet(object):
     from nctoolkit.monthlyclim import monthly_max_climatology
     from nctoolkit.monthlyclim import monthly_range_climatology
 
-    from nctoolkit.dailyclim import daily_mean_climatology
-    from nctoolkit.dailyclim import daily_min_climatology
-    from nctoolkit.dailyclim import daily_max_climatology
-    from nctoolkit.dailyclim import daily_range_climatology
+    from nctoolkit.nco_command import nco_command
 
-    from nctoolkit.to_nc import write_nc
+    from nctoolkit.phenology import phenology
+
+    from nctoolkit.plot import plot
+
+    from nctoolkit.reduce import reduce_dims
+
+    from nctoolkit.reduce_grid import reduce_grid
+
+    from nctoolkit.regrid import regrid
+
+    from nctoolkit.release import run
 
     from nctoolkit.rename import rename
 
-    from nctoolkit.setters import set_date
-    from nctoolkit.setters import set_missing
-    from nctoolkit.setters import set_units
-    from nctoolkit.setters import set_longnames
-
-    from nctoolkit.time_stat import mean
-    from nctoolkit.time_stat import percentile
-    from nctoolkit.time_stat import max
-    from nctoolkit.time_stat import min
-    from nctoolkit.time_stat import range
-    from nctoolkit.time_stat import var
-    from nctoolkit.time_stat import sum
-    from nctoolkit.time_stat import cum_sum
-
-    from nctoolkit.release import release
-    from nctoolkit.release import run
-
-    from nctoolkit.delete import remove_variables
-
-    from nctoolkit.mergers import merge_time
-    from nctoolkit.mergers import merge
+    from nctoolkit.resample import resample_grid
 
     from nctoolkit.rollstat import rolling_mean
     from nctoolkit.rollstat import rolling_min
@@ -882,12 +932,55 @@ class DataSet(object):
     from nctoolkit.rollstat import rolling_range
     from nctoolkit.rollstat import rolling_sum
 
-    from nctoolkit.fldstat import spatial_mean
-    from nctoolkit.fldstat import spatial_min
-    from nctoolkit.fldstat import spatial_max
-    from nctoolkit.fldstat import spatial_range
-    from nctoolkit.fldstat import spatial_sum
-    from nctoolkit.fldstat import spatial_percentile
+    from nctoolkit.seasclim import seasonal_mean_climatology
+    from nctoolkit.seasclim import seasonal_min_climatology
+    from nctoolkit.seasclim import seasonal_max_climatology
+    from nctoolkit.seasclim import seasonal_range_climatology
+
+    from nctoolkit.seasstat import seasonal_mean
+    from nctoolkit.seasstat import seasonal_min
+    from nctoolkit.seasstat import seasonal_max
+    from nctoolkit.seasstat import seasonal_range
+
+    from nctoolkit.select import select_variables
+    from nctoolkit.select import select_timesteps
+    from nctoolkit.select import select_seasons
+    from nctoolkit.select import select_months
+    from nctoolkit.select import select_years
+    from nctoolkit.select import select
+
+    from nctoolkit.setters import set_date
+    from nctoolkit.setters import set_missing
+    from nctoolkit.setters import set_units
+    from nctoolkit.setters import set_longnames
+
+    from nctoolkit.shift import shift_hours
+    from nctoolkit.shift import shift_days
+    from nctoolkit.shift import shift_months
+    from nctoolkit.shift import shift_years
+    from nctoolkit.shift import shift
+
+    from nctoolkit.split import split
+
+    from nctoolkit.strip_vars import strip_variables
+
+    from nctoolkit.time_stat import mean
+    from nctoolkit.time_stat import percentile
+    from nctoolkit.time_stat import max
+    from nctoolkit.time_stat import median
+    from nctoolkit.time_stat import min
+    from nctoolkit.time_stat import range
+    from nctoolkit.time_stat import var
+    from nctoolkit.time_stat import sum
+    from nctoolkit.time_stat import cum_sum
+
+    from nctoolkit.to_lonlat import to_latlon
+
+    from nctoolkit.to_nc import write_nc
+    from nctoolkit.to_nc import to_nc
+
+    from nctoolkit.toxarray import to_xarray
+    from nctoolkit.toxarray import to_dataframe
 
     from nctoolkit.verticals import vertical_mean
     from nctoolkit.verticals import vertical_min
@@ -903,50 +996,23 @@ class DataSet(object):
 
     from nctoolkit.view import view
 
+    from nctoolkit.yearlystat import annual_mean
+    from nctoolkit.yearlystat import annual_min
+    from nctoolkit.yearlystat import annual_max
+    from nctoolkit.yearlystat import annual_range
+    from nctoolkit.yearlystat import annual_sum
+
     from nctoolkit.zip import zip
 
-    from nctoolkit.corr import cor_space
-    from nctoolkit.corr import cor_time
-
-    from nctoolkit.phenology import phenology
-
-    from nctoolkit.split import split
-
-    from nctoolkit.anomaly import annual_anomaly
-    from nctoolkit.anomaly import monthly_anomaly
-
-    from nctoolkit.masking import mask_box
-
-    from nctoolkit.inttime import time_interp
-
-    from nctoolkit.cleanup import disk_clean
-
-    from nctoolkit.plot import plot
-
-    from nctoolkit.compare import compare_all
-
-    from nctoolkit.add_etc import add
-    from nctoolkit.add_etc import subtract
-    from nctoolkit.add_etc import multiply
-    from nctoolkit.add_etc import divide
-
-    from nctoolkit.to_lonlat import to_latlon
-
-    from nctoolkit.reduce import reduce_dims
-
-    from nctoolkit.reduce_grid import reduce_grid
-
     from nctoolkit.zonals import zonal_mean
     from nctoolkit.zonals import zonal_min
     from nctoolkit.zonals import zonal_max
     from nctoolkit.zonals import zonal_range
 
-    from nctoolkit.shift import shift_hours
-    from nctoolkit.shift import shift_days
+# deprecated stuff
 
-    from nctoolkit.append import append
+    from nctoolkit.deprecated import clip
 
-    from nctoolkit.meridonials import meridonial_mean
-    from nctoolkit.meridonials import meridonial_min
-    from nctoolkit.meridonials import meridonial_max
-    from nctoolkit.meridonials import meridonial_range
+    from nctoolkit.deprecated import release
+    from nctoolkit.deprecated import select_timestep
+    from nctoolkit.deprecated import select_season
